WHITELIST_IPS = ["127.0.0.1", "192.168.1.100"]
BLACKLIST_IPS = ["10.0.0.5", "10.0.0.6"]

# Default restriction mode for all views
# Options: "whitelist", "blacklist", or False
DEFAULT_IP_RESTRICTION_MODE = False
